##  Step 4: Create New Report Versions
Once the report is published, you can create new report versions. To do that, in the Reports section of the SAP LeanIX Store dashboard, navigate to Published Reports, then click Create New Version.
You can submit updated versions of your reports featuring improvements, added functionalities, or bug fixes. These new versions will undergo the same review process as a new report.
Please ensure to increment the version number in your GitLab project's package.json file when submitting a new version, otherwise uploading the report to a workspace may result in an error.
![Overview of Published Reports in the SAP LeanIX Store Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741fc7f7a4410149401a80e2eb3e01d_LowRes.png)
Overview of Published Reports in the SAP LeanIX Store Dashboard
YesNo
Send
Help us provide a better digital experience for you and all other visitors.
What is the purpose of your visit to our website today?
  * Understand software features and benefits for a possible purchase
  * Find information about how to use the software
  * Find implementation or configuration information
  * Find information on installing or upgrading the software
  * Find information to troubleshoot and resolve issues that I'm encountering
  * Find developer or API information
  * Learn about new or updated product features
  * Other (please specify)


You can write a maximum of 255 characters.
Were you able to complete your task?
  * Yes
  * No


Why were you not able to complete your task today?
You can write a maximum of 4000 characters.
